# CVTK Python API

[CVTK](https://github.com/willard-yuan/cvtk), a Computer Vision ToolKit. The project provides Python API for CVTK. More details can be access to [Pypi](https://pypi.org/project/cvtk-release/).


## Installation

```bash
pip install cvtk-release
```

## Test call

```python
import cvtk
cvtk.add(1, 2)
```

## License

CVTK is provided under a BSD-style license that can be found in the LICENSE
file. By using, distributing, or contributing to this project, you agree to the
terms and conditions of this license.
